@@ -6,7 +6,7 @@ package Mite::Attribute;
 use Mite::Miteception qw( -all !lazy );
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.009003';
+our $VERSION   = '0.010000';
 
 use B ();
 use List::Util ();
@@ -24,18 +24,18 @@ has definition_context =>
 
 has class =>
   is            => rw,
-  isa           => MiteRole,
+  isa           => MitePackage,
   weak_ref      => true;
 
 has compiling_class =>
   init_arg      => undef,
   is            => rw,
-  isa           => MiteRole,
+  isa           => MitePackage,
   local_writer  => true;
 
 has _class_for_default =>
   is            => rw,
-  isa           => MiteRole,
+  isa           => MitePackage,
   weak_ref      => true,
   lazy          => true,
   builder       => sub { $_[0]->class || $_[0]->compiling_class };
@@ -1430,42 +1430,3 @@ CODE
 }
 
 1;
-
-__END__
-
-=pod
-
-=head1 NAME
-
-Mite::Attribute - an attribute in a class or role
-
-=head1 DESCRIPTION
-
-NO USER SERVICABLE PARTS INSIDE.  This is a private class.
-
-=head1 BUGS
-
-Please report any bugs to L<https://github.com/tobyink/p5-mite/issues>.
-
-=head1 AUTHOR
-
-Michael G Schwern E<lt>mschwern@cpan.orgE<gt>.
-
-Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
-
-=head1 COPYRIGHT AND LICENCE
-
-This software is copyright (c) 2011-2014 by Michael G Schwern.
-
-This software is copyright (c) 2022 by Toby Inkster.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=head1 DISCLAIMER OF WARRANTIES
-
-THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
-WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
-MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-
-=cut
