@@ -26,12 +26,33 @@
         *true    = \&Mite::Shim::true;
     }
 
+    # Gather metadata for constructor and destructor
+    sub __META__ {
+        no strict 'refs';
+        no warnings 'once';
+        my $class = shift;
+        $class = ref($class) || $class;
+        my $linear_isa = mro::get_linear_isa($class);
+        return {
+            BUILD => [
+                map { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
+                map { "$_\::BUILD" } reverse @$linear_isa
+            ],
+            DEMOLISH => [
+                map   { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
+                  map { "$_\::DEMOLISH" } @$linear_isa
+            ],
+            HAS_BUILDARGS        => $class->can('BUILDARGS'),
+            HAS_FOREIGNBUILDARGS => $class->can('FOREIGNBUILDARGS'),
+        };
+    }
+
     BEGIN {
-        require Mite::Role;
+        require Mite::Package;
 
         use mro 'c3';
         our @ISA;
-        push @ISA, "Mite::Role";
+        push @ISA, "Mite::Package";
     }
 
     # Standard Moose/Moo-style constructor
@@ -45,38 +66,8 @@
           : { ( @_ == 1 ) ? %{ $_[0] } : @_ };
         my $no_build = delete $args->{__no_BUILD__};
 
-        # Attribute attributes (type: HashRef[Mite::Attribute])
-        # has declaration, file lib/Mite/Role.pm, line 21
-        do {
-            my $value =
-              exists( $args->{"attributes"} )
-              ? $args->{"attributes"}
-              : $Mite::Role::__attributes_DEFAULT__->($self);
-            do {
-
-                package Mite::Shim;
-                ( ref($value) eq 'HASH' ) and do {
-                    my $ok = 1;
-                    for my $i ( values %{$value} ) {
-                        ( $ok = 0, last )
-                          unless (
-                            do {
-                                use Scalar::Util ();
-                                Scalar::Util::blessed($i)
-                                  and $i->isa(q[Mite::Attribute]);
-                            }
-                          );
-                    };
-                    $ok;
-                }
-              }
-              or croak "Type check failed in constructor: %s should be %s",
-              "attributes", "HashRef[Mite::Attribute]";
-            $self->{"attributes"} = $value;
-        };
-
         # Attribute name (type: ValidClassName)
-        # has declaration, file lib/Mite/Role.pm, line 23
+        # has declaration, file lib/Mite/Package.pm, line 11
         croak "Missing key in constructor: name" unless exists $args->{"name"};
         (
             (
@@ -101,7 +92,7 @@
         $self->{"name"} = $args->{"name"};
 
         # Attribute shim_name (type: ValidClassName)
-        # has declaration, file lib/Mite/Role.pm, line 35
+        # has declaration, file lib/Mite/Package.pm, line 23
         if ( exists $args->{"shim_name"} ) {
             (
                 (
@@ -128,7 +119,7 @@
         }
 
         # Attribute source (type: Mite::Source)
-        # has declaration, file lib/Mite/Role.pm, line 37
+        # has declaration, file lib/Mite/Package.pm, line 25
         if ( exists $args->{"source"} ) {
             blessed( $args->{"source"} )
               && $args->{"source"}->isa("Mite::Source")
@@ -139,82 +130,8 @@
         require Scalar::Util && Scalar::Util::weaken( $self->{"source"} )
           if ref $self->{"source"};
 
-        # Attribute roles (type: ArrayRef[Mite::Role])
-        # has declaration, file lib/Mite/Role.pm, line 46
-        do {
-            my $value =
-              exists( $args->{"roles"} )
-              ? $args->{"roles"}
-              : $self->_build_roles;
-            do {
-
-                package Mite::Shim;
-                ( ref($value) eq 'ARRAY' ) and do {
-                    my $ok = 1;
-                    for my $i ( @{$value} ) {
-                        ( $ok = 0, last )
-                          unless (
-                            do {
-                                use Scalar::Util ();
-                                Scalar::Util::blessed($i)
-                                  and $i->isa(q[Mite::Role]);
-                            }
-                          );
-                    };
-                    $ok;
-                }
-              }
-              or croak "Type check failed in constructor: %s should be %s",
-              "roles", "ArrayRef[Mite::Role]";
-            $self->{"roles"} = $value;
-        };
-
-        # Attribute role_args (type: Map[NonEmptyStr,HashRef|Undef])
-        # has declaration, file lib/Mite/Role.pm, line 51
-        do {
-            my $value =
-              exists( $args->{"role_args"} )
-              ? $args->{"role_args"}
-              : $self->_build_role_args;
-            do {
-
-                package Mite::Shim;
-                ( ref($value) eq 'HASH' ) and do {
-                    my $ok = 1;
-                    for my $v ( values %{$value} ) {
-                        ( $ok = 0, last ) unless do {
-
-                            package Mite::Shim;
-                            ( ( ref($v) eq 'HASH' ) or ( !defined($v) ) );
-                        }
-                    };
-                    for my $k ( keys %{$value} ) {
-                        ( $ok = 0, last )
-                          unless (
-                            (
-                                do {
-
-                                    package Mite::Shim;
-                                    defined($k) and do {
-                                        ref( \$k ) eq 'SCALAR'
-                                          or ref( \( my $val = $k ) ) eq
-                                          'SCALAR';
-                                    }
-                                }
-                            )
-                            && ( length($k) > 0 )
-                          );
-                    };
-                    $ok;
-                }
-              }
-              or croak "Type check failed in constructor: %s should be %s",
-              "role_args", "Map[NonEmptyStr,HashRef|Undef]";
-            $self->{"role_args"} = $value;
-        };
-
         # Attribute imported_functions (type: Map[MethodName,Str])
-        # has declaration, file lib/Mite/Role.pm, line 56
+        # has declaration, file lib/Mite/Package.pm, line 34
         do {
             my $value =
               exists( $args->{"imported_functions"} )
@@ -260,13 +177,14 @@
             $self->{"imported_functions"} = $value;
         };
 
-        # Attribute required_methods (type: ArrayRef[MethodName])
-        # has declaration, file lib/Mite/Role.pm, line 61
+        # Attribute extends (type: ArrayRef[ValidClassName])
+        # has declaration, file lib/Mite/Trait/HasSuperclasses.pm, line 28
         do {
             my $value =
-              exists( $args->{"required_methods"} )
-              ? $args->{"required_methods"}
-              : $self->_build_required_methods;
+              exists( $args->{"extends"} )
+              ? $args->{"extends"}
+              : $Mite::Trait::HasSuperclasses::__extends_DEFAULT__->(
+                $self);
             do {
 
                 package Mite::Shim;
@@ -286,19 +204,199 @@
                                     }
                                 }
                             )
-                            && ( do { local $_ = $i; /\A[^\W0-9]\w*\z/ } )
+                            && (
+                                do {
+                                    local $_ = $i;
+                                    /\A[^\W0-9]\w*(?:::[^\W0-9]\w*)*\z/;
+                                }
+                            )
                           );
                     };
                     $ok;
                 }
               }
               or croak "Type check failed in constructor: %s should be %s",
-              "required_methods", "ArrayRef[MethodName]";
-            $self->{"required_methods"} = $value;
+              "extends", "ArrayRef[ValidClassName]";
+            $self->{"extends"} = $value;
+            $self->_trigger_extends( $self->{"extends"} );
+        };
+
+        # Attribute superclass_args (type: Map[NonEmptyStr,HashRef|Undef])
+        # has declaration, file lib/Mite/Trait/HasSuperclasses.pm, line 33
+        do {
+            my $value =
+              exists( $args->{"superclass_args"} )
+              ? $args->{"superclass_args"}
+              : $self->_build_superclass_args;
+            do {
+
+                package Mite::Shim;
+                ( ref($value) eq 'HASH' ) and do {
+                    my $ok = 1;
+                    for my $v ( values %{$value} ) {
+                        ( $ok = 0, last ) unless do {
+
+                            package Mite::Shim;
+                            ( ( ref($v) eq 'HASH' ) or ( !defined($v) ) );
+                        }
+                    };
+                    for my $k ( keys %{$value} ) {
+                        ( $ok = 0, last )
+                          unless (
+                            (
+                                do {
+
+                                    package Mite::Shim;
+                                    defined($k) and do {
+                                        ref( \$k ) eq 'SCALAR'
+                                          or ref( \( my $val = $k ) ) eq
+                                          'SCALAR';
+                                    }
+                                }
+                            )
+                            && ( length($k) > 0 )
+                          );
+                    };
+                    $ok;
+                }
+              }
+              or croak "Type check failed in constructor: %s should be %s",
+              "superclass_args", "Map[NonEmptyStr,HashRef|Undef]";
+            $self->{"superclass_args"} = $value;
+        };
+
+        # Attribute parents (type: ArrayRef[Mite::Class])
+        # has declaration, file lib/Mite/Trait/HasSuperclasses.pm, line 36
+        if ( exists $args->{"parents"} ) {
+            (
+                do { package Mite::Shim; ref( $args->{"parents"} ) eq 'ARRAY' }
+                  and do {
+                    my $ok = 1;
+                    for my $i ( @{ $args->{"parents"} } ) {
+                        ( $ok = 0, last )
+                          unless (
+                            do {
+                                use Scalar::Util ();
+                                Scalar::Util::blessed($i)
+                                  and $i->isa(q[Mite::Class]);
+                            }
+                          );
+                    };
+                    $ok;
+                }
+              )
+              or croak "Type check failed in constructor: %s should be %s",
+              "parents", "ArrayRef[Mite::Class]";
+            $self->{"parents"} = $args->{"parents"};
+        }
+
+        # Attribute attributes (type: HashRef[Mite::Attribute])
+        # has declaration, file lib/Mite/Trait/HasAttributes.pm, line 16
+        do {
+            my $value =
+              exists( $args->{"attributes"} )
+              ? $args->{"attributes"}
+              : $Mite::Trait::HasAttributes::__attributes_DEFAULT__
+              ->($self);
+            do {
+
+                package Mite::Shim;
+                ( ref($value) eq 'HASH' ) and do {
+                    my $ok = 1;
+                    for my $i ( values %{$value} ) {
+                        ( $ok = 0, last )
+                          unless (
+                            do {
+                                use Scalar::Util ();
+                                Scalar::Util::blessed($i)
+                                  and $i->isa(q[Mite::Attribute]);
+                            }
+                          );
+                    };
+                    $ok;
+                }
+              }
+              or croak "Type check failed in constructor: %s should be %s",
+              "attributes", "HashRef[Mite::Attribute]";
+            $self->{"attributes"} = $value;
+        };
+
+        # Attribute roles (type: ArrayRef[Mite::Role])
+        # has declaration, file lib/Mite/Trait/HasRoles.pm, line 19
+        do {
+            my $value =
+              exists( $args->{"roles"} )
+              ? $args->{"roles"}
+              : $self->_build_roles;
+            do {
+
+                package Mite::Shim;
+                ( ref($value) eq 'ARRAY' ) and do {
+                    my $ok = 1;
+                    for my $i ( @{$value} ) {
+                        ( $ok = 0, last )
+                          unless (
+                            do {
+                                use Scalar::Util ();
+                                Scalar::Util::blessed($i)
+                                  and $i->isa(q[Mite::Role]);
+                            }
+                          );
+                    };
+                    $ok;
+                }
+              }
+              or croak "Type check failed in constructor: %s should be %s",
+              "roles", "ArrayRef[Mite::Role]";
+            $self->{"roles"} = $value;
+        };
+
+        # Attribute role_args (type: Map[NonEmptyStr,HashRef|Undef])
+        # has declaration, file lib/Mite/Trait/HasRoles.pm, line 24
+        do {
+            my $value =
+              exists( $args->{"role_args"} )
+              ? $args->{"role_args"}
+              : $self->_build_role_args;
+            do {
+
+                package Mite::Shim;
+                ( ref($value) eq 'HASH' ) and do {
+                    my $ok = 1;
+                    for my $v ( values %{$value} ) {
+                        ( $ok = 0, last ) unless do {
+
+                            package Mite::Shim;
+                            ( ( ref($v) eq 'HASH' ) or ( !defined($v) ) );
+                        }
+                    };
+                    for my $k ( keys %{$value} ) {
+                        ( $ok = 0, last )
+                          unless (
+                            (
+                                do {
+
+                                    package Mite::Shim;
+                                    defined($k) and do {
+                                        ref( \$k ) eq 'SCALAR'
+                                          or ref( \( my $val = $k ) ) eq
+                                          'SCALAR';
+                                    }
+                                }
+                            )
+                            && ( length($k) > 0 )
+                          );
+                    };
+                    $ok;
+                }
+              }
+              or croak "Type check failed in constructor: %s should be %s",
+              "role_args", "Map[NonEmptyStr,HashRef|Undef]";
+            $self->{"role_args"} = $value;
         };
 
         # Attribute method_signatures (type: Map[MethodName,Mite::Signature])
-        # has declaration, file lib/Mite/Role.pm, line 66
+        # has declaration, file lib/Mite/Trait/HasMethods.pm, line 20
         do {
             my $value =
               exists( $args->{"method_signatures"} )
@@ -344,124 +442,12 @@
             $self->{"method_signatures"} = $value;
         };
 
-        # Attribute extends (type: ArrayRef[ValidClassName])
-        # has declaration, file lib/Mite/Class.pm, line 33
-        do {
-            my $value =
-              exists( $args->{"extends"} )
-              ? $args->{"extends"}
-              : $Mite::Class::__extends_DEFAULT__->($self);
-            do {
-
-                package Mite::Shim;
-                ( ref($value) eq 'ARRAY' ) and do {
-                    my $ok = 1;
-                    for my $i ( @{$value} ) {
-                        ( $ok = 0, last )
-                          unless (
-                            (
-                                do {
-
-                                    package Mite::Shim;
-                                    defined($i) and do {
-                                        ref( \$i ) eq 'SCALAR'
-                                          or ref( \( my $val = $i ) ) eq
-                                          'SCALAR';
-                                    }
-                                }
-                            )
-                            && (
-                                do {
-                                    local $_ = $i;
-                                    /\A[^\W0-9]\w*(?:::[^\W0-9]\w*)*\z/;
-                                }
-                            )
-                          );
-                    };
-                    $ok;
-                }
-              }
-              or croak "Type check failed in constructor: %s should be %s",
-              "extends", "ArrayRef[ValidClassName]";
-            $self->{"extends"} = $value;
-            $self->_trigger_extends( $self->{"extends"} );
-        };
-
-        # Attribute superclass_args (type: Map[NonEmptyStr,HashRef|Undef])
-        # has declaration, file lib/Mite/Class.pm, line 38
-        do {
-            my $value =
-              exists( $args->{"superclass_args"} )
-              ? $args->{"superclass_args"}
-              : $self->_build_superclass_args;
-            do {
-
-                package Mite::Shim;
-                ( ref($value) eq 'HASH' ) and do {
-                    my $ok = 1;
-                    for my $v ( values %{$value} ) {
-                        ( $ok = 0, last ) unless do {
-
-                            package Mite::Shim;
-                            ( ( ref($v) eq 'HASH' ) or ( !defined($v) ) );
-                        }
-                    };
-                    for my $k ( keys %{$value} ) {
-                        ( $ok = 0, last )
-                          unless (
-                            (
-                                do {
-
-                                    package Mite::Shim;
-                                    defined($k) and do {
-                                        ref( \$k ) eq 'SCALAR'
-                                          or ref( \( my $val = $k ) ) eq
-                                          'SCALAR';
-                                    }
-                                }
-                            )
-                            && ( length($k) > 0 )
-                          );
-                    };
-                    $ok;
-                }
-              }
-              or croak "Type check failed in constructor: %s should be %s",
-              "superclass_args", "Map[NonEmptyStr,HashRef|Undef]";
-            $self->{"superclass_args"} = $value;
-        };
-
-        # Attribute parents (type: ArrayRef[Mite::Class])
-        # has declaration, file lib/Mite/Class.pm, line 41
-        if ( exists $args->{"parents"} ) {
-            (
-                do { package Mite::Shim; ref( $args->{"parents"} ) eq 'ARRAY' }
-                  and do {
-                    my $ok = 1;
-                    for my $i ( @{ $args->{"parents"} } ) {
-                        ( $ok = 0, last )
-                          unless (
-                            do {
-                                use Scalar::Util ();
-                                Scalar::Util::blessed($i)
-                                  and $i->isa(q[Mite::Class]);
-                            }
-                          );
-                    };
-                    $ok;
-                }
-              )
-              or croak "Type check failed in constructor: %s should be %s",
-              "parents", "ArrayRef[Mite::Class]";
-            $self->{"parents"} = $args->{"parents"};
-        }
-
         # Call BUILD methods
         $self->BUILDALL($args) if ( !$no_build and @{ $meta->{BUILD} || [] } );
 
         # Unrecognized parameters
         my @unknown = grep not(
-/\A(?:attributes|extends|imported_functions|method_signatures|name|parents|r(?:equired_methods|ole(?:_args|s))|s(?:him_name|ource|uperclass_args))\z/
+/\A(?:attributes|extends|imported_functions|method_signatures|name|parents|role(?:_args|s)|s(?:him_name|ource|uperclass_args))\z/
         ), keys %{$args};
         @unknown
           and croak(
@@ -470,25 +456,26 @@
         return $self;
     }
 
-    # See UNIVERSAL
-    sub DOES {
-        my ( $self, $role ) = @_;
-        our %DOES;
-        return $DOES{$role} if exists $DOES{$role};
-        return 1            if $role eq __PACKAGE__;
-        return $self->SUPER::DOES($role);
-    }
-
-    # Alias for Moose/Moo-compatibility
-    sub does {
-        shift->DOES(@_);
-    }
-
     my $__XS = !$ENV{MITE_PURE_PERL}
       && eval { require Class::XSAccessor; Class::XSAccessor->VERSION("1.19") };
 
+    # Accessors for attributes
+    # has declaration, file lib/Mite/Trait/HasAttributes.pm, line 16
+    if ($__XS) {
+        Class::XSAccessor->import(
+            chained   => 1,
+            "getters" => { "attributes" => "attributes" },
+        );
+    }
+    else {
+        *attributes = sub {
+            @_ == 1 or croak('Reader "attributes" usage: $self->attributes()');
+            $_[0]{"attributes"};
+        };
+    }
+
     # Accessors for extends
-    # has declaration, file lib/Mite/Class.pm, line 33
+    # has declaration, file lib/Mite/Trait/HasSuperclasses.pm, line 28
     sub superclasses {
         @_ > 1
           ? do {
@@ -533,8 +520,25 @@
           : ( $_[0]{"extends"} );
     }
 
+    # Accessors for method_signatures
+    # has declaration, file lib/Mite/Trait/HasMethods.pm, line 20
+    if ($__XS) {
+        Class::XSAccessor->import(
+            chained   => 1,
+            "getters" => { "method_signatures" => "method_signatures" },
+        );
+    }
+    else {
+        *method_signatures = sub {
+            @_ == 1
+              or croak(
+                'Reader "method_signatures" usage: $self->method_signatures()');
+            $_[0]{"method_signatures"};
+        };
+    }
+
     # Accessors for parents
-    # has declaration, file lib/Mite/Class.pm, line 41
+    # has declaration, file lib/Mite/Trait/HasSuperclasses.pm, line 36
     sub _clear_parents {
         @_ == 1
           or croak('Clearer "_clear_parents" usage: $self->_clear_parents()');
@@ -574,8 +578,84 @@
         );
     }
 
+    # Accessors for role_args
+    # has declaration, file lib/Mite/Trait/HasRoles.pm, line 24
+    sub role_args {
+        @_ > 1
+          ? do {
+            do {
+
+                package Mite::Shim;
+                ( ref( $_[1] ) eq 'HASH' ) and do {
+                    my $ok = 1;
+                    for my $v ( values %{ $_[1] } ) {
+                        ( $ok = 0, last ) unless do {
+
+                            package Mite::Shim;
+                            ( ( ref($v) eq 'HASH' ) or ( !defined($v) ) );
+                        }
+                    };
+                    for my $k ( keys %{ $_[1] } ) {
+                        ( $ok = 0, last )
+                          unless (
+                            (
+                                do {
+
+                                    package Mite::Shim;
+                                    defined($k) and do {
+                                        ref( \$k ) eq 'SCALAR'
+                                          or ref( \( my $val = $k ) ) eq
+                                          'SCALAR';
+                                    }
+                                }
+                            )
+                            && ( length($k) > 0 )
+                          );
+                    };
+                    $ok;
+                }
+              }
+              or croak( "Type check failed in %s: value should be %s",
+                "accessor", "Map[NonEmptyStr,HashRef|Undef]" );
+            $_[0]{"role_args"} = $_[1];
+            $_[0];
+          }
+          : ( $_[0]{"role_args"} );
+    }
+
+    # Accessors for roles
+    # has declaration, file lib/Mite/Trait/HasRoles.pm, line 19
+    sub roles {
+        @_ > 1
+          ? do {
+            do {
+
+                package Mite::Shim;
+                ( ref( $_[1] ) eq 'ARRAY' ) and do {
+                    my $ok = 1;
+                    for my $i ( @{ $_[1] } ) {
+                        ( $ok = 0, last )
+                          unless (
+                            do {
+                                use Scalar::Util ();
+                                Scalar::Util::blessed($i)
+                                  and $i->isa(q[Mite::Role]);
+                            }
+                          );
+                    };
+                    $ok;
+                }
+              }
+              or croak( "Type check failed in %s: value should be %s",
+                "accessor", "ArrayRef[Mite::Role]" );
+            $_[0]{"roles"} = $_[1];
+            $_[0];
+          }
+          : ( $_[0]{"roles"} );
+    }
+
     # Accessors for superclass_args
-    # has declaration, file lib/Mite/Class.pm, line 38
+    # has declaration, file lib/Mite/Trait/HasSuperclasses.pm, line 33
     sub superclass_args {
         @_ > 1
           ? do {
@@ -619,5 +699,193 @@
           : ( $_[0]{"superclass_args"} );
     }
 
+    BEGIN {
+        require Mite::Trait::HasSuperclasses;
+        require Mite::Trait::HasConstructor;
+        require Mite::Trait::HasDestructor;
+        require Mite::Trait::HasAttributes;
+        require Mite::Trait::HasRoles;
+        require Mite::Trait::HasMethods;
+        require Mite::Trait::HasMOP;
+
+        our %DOES = (
+            "Mite::Class"                  => 1,
+            "Mite::Trait::HasSuperclasses" => 1,
+            "Mite::Trait::HasConstructor"  => 1,
+            "Mite::Trait::HasDestructor"   => 1,
+            "Mite::Trait::HasAttributes"   => 1,
+            "Mite::Trait::HasRoles"        => 1,
+            "Mite::Trait::HasMethods"      => 1,
+            "Mite::Trait::HasMOP"          => 1
+        );
+    }
+
+    # See UNIVERSAL
+    sub DOES {
+        my ( $self, $role ) = @_;
+        our %DOES;
+        return $DOES{$role} if exists $DOES{$role};
+        return 1            if $role eq __PACKAGE__;
+        return $self->SUPER::DOES($role);
+    }
+
+    # Alias for Moose/Moo-compatibility
+    sub does {
+        shift->DOES(@_);
+    }
+
+    # Methods from roles
+    sub _all_subs { goto \&Mite::Trait::HasMethods::_all_subs; }
+
+    sub _build_method_signatures {
+        goto \&Mite::Trait::HasMethods::_build_method_signatures;
+    }
+
+    sub _build_parents {
+        goto \&Mite::Trait::HasSuperclasses::_build_parents;
+    }
+
+    sub _build_role_args {
+        goto \&Mite::Trait::HasRoles::_build_role_args;
+    }
+    sub _build_roles { goto \&Mite::Trait::HasRoles::_build_roles; }
+
+    sub _build_superclass_args {
+        goto \&Mite::Trait::HasSuperclasses::_build_superclass_args;
+    }
+
+    sub _compile_attribute_accessors {
+        goto
+          \&Mite::Trait::HasAttributes::_compile_attribute_accessors;
+    }
+
+    sub _compile_bless {
+        goto \&Mite::Trait::HasConstructor::_compile_bless;
+    }
+
+    sub _compile_buildall {
+        goto \&Mite::Trait::HasConstructor::_compile_buildall;
+    }
+
+    sub _compile_buildall_method {
+        goto \&Mite::Trait::HasConstructor::_compile_buildall_method;
+    }
+
+    sub _compile_buildargs {
+        goto \&Mite::Trait::HasConstructor::_compile_buildargs;
+    }
+
+    sub _compile_composed_methods {
+        goto \&Mite::Trait::HasRoles::_compile_composed_methods;
+    }
+
+    sub _compile_destroy {
+        goto \&Mite::Trait::HasDestructor::_compile_destroy;
+    }
+    sub _compile_does { goto \&Mite::Trait::HasRoles::_compile_does; }
+
+    sub _compile_extends {
+        goto \&Mite::Trait::HasSuperclasses::_compile_extends;
+    }
+
+    sub _compile_init_attributes {
+        goto \&Mite::Trait::HasAttributes::_compile_init_attributes;
+    }
+
+    sub _compile_method_signatures {
+        goto \&Mite::Trait::HasMethods::_compile_method_signatures;
+    }
+    sub _compile_mop { goto \&Mite::Trait::HasMOP::_compile_mop; }
+
+    sub _compile_mop_attributes {
+        goto \&Mite::Trait::HasMOP::_compile_mop_attributes;
+    }
+
+    sub _compile_mop_methods {
+        goto \&Mite::Trait::HasMOP::_compile_mop_methods;
+    }
+
+    sub _compile_mop_modifiers {
+        goto \&Mite::Trait::HasMOP::_compile_mop_modifiers;
+    }
+
+    sub _compile_mop_required_methods {
+        goto \&Mite::Trait::HasMOP::_compile_mop_required_methods;
+    }
+
+    sub _compile_mop_tc {
+        goto \&Mite::Trait::HasMOP::_compile_mop_tc;
+    }
+
+    sub _compile_new {
+        goto \&Mite::Trait::HasConstructor::_compile_new;
+    }
+
+    sub _compile_strict_constructor {
+        goto
+          \&Mite::Trait::HasConstructor::_compile_strict_constructor;
+    }
+    sub _compile_with { goto \&Mite::Trait::HasRoles::_compile_with; }
+
+    sub _get_parent {
+        goto \&Mite::Trait::HasSuperclasses::_get_parent;
+    }
+    sub _get_role { goto \&Mite::Trait::HasRoles::_get_role; }
+    sub _set_isa  { goto \&Mite::Trait::HasSuperclasses::_set_isa; }
+
+    sub _trigger_extends {
+        goto \&Mite::Trait::HasSuperclasses::_trigger_extends;
+    }
+
+    sub add_attribute {
+        goto \&Mite::Trait::HasAttributes::add_attribute;
+    }
+
+    sub add_attributes {
+        goto \&Mite::Trait::HasAttributes::add_attributes;
+    }
+
+    sub add_method_signature {
+        goto \&Mite::Trait::HasMethods::add_method_signature;
+    }
+    sub add_role { goto \&Mite::Trait::HasRoles::add_role; }
+
+    sub add_roles_by_name {
+        goto \&Mite::Trait::HasRoles::add_roles_by_name;
+    }
+
+    sub all_attributes {
+        goto \&Mite::Trait::HasAttributes::all_attributes;
+    }
+    sub does_list { goto \&Mite::Trait::HasRoles::does_list; }
+
+    sub extend_attribute {
+        goto \&Mite::Trait::HasAttributes::extend_attribute;
+    }
+    sub get_isa { goto \&Mite::Trait::HasSuperclasses::get_isa; }
+
+    sub handle_extends_keyword {
+        goto \&Mite::Trait::HasSuperclasses::handle_extends_keyword;
+    }
+
+    sub handle_with_keyword {
+        goto \&Mite::Trait::HasRoles::handle_with_keyword;
+    }
+    sub linear_isa {
+        goto \&Mite::Trait::HasSuperclasses::linear_isa;
+    }
+
+    sub linear_parents {
+        goto \&Mite::Trait::HasSuperclasses::linear_parents;
+    }
+
+    sub methods_to_import_from_roles {
+        goto \&Mite::Trait::HasRoles::methods_to_import_from_roles;
+    }
+
+    sub native_methods {
+        goto \&Mite::Trait::HasMethods::native_methods;
+    }
+
     1;
 }
