@@ -6,7 +6,7 @@ package Mite::Compiled;
 use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.009003';
+our $VERSION   = '0.010000';
 
 use Path::Tiny;
 
@@ -92,54 +92,3 @@ sub _source_file2compiled_file {
 }
 
 1;
-
-__END__
-
-=pod
-
-=head1 NAME
-
-Mite::Compiled - the extra compiled module file written by Mite
-
-=head1 SYNOPSIS
-
-    use Mite::Compiled;
-    my $compiled = Mite::Compiled->new( source => $source );
-
-=head1 DESCRIPTION
-
-NO USER SERVICABLE PARTS INSIDE.  This is a private class.
-
-Represents the extra file written by Mite containing the compiled code.
-
-There is a one-to-one mapping between a source file and a compiled
-file, but there can be many Mite classes in one file.  Mite::Compiled
-manages the compliation and ensures classes don't write over each
-other.
-
-=head1 BUGS
-
-Please report any bugs to L<https://github.com/tobyink/p5-mite/issues>.
-
-=head1 AUTHOR
-
-Michael G Schwern E<lt>mschwern@cpan.orgE<gt>.
-
-Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
-
-=head1 COPYRIGHT AND LICENCE
-
-This software is copyright (c) 2011-2014 by Michael G Schwern.
-
-This software is copyright (c) 2022 by Toby Inkster.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=head1 DISCLAIMER OF WARRANTIES
-
-THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
-WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
-MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-
-=cut
