@@ -6,7 +6,7 @@ package Mite::Project;
 use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.009003';
+our $VERSION   = '0.010000';
 
 has sources =>
   is            => ro,
@@ -145,22 +145,29 @@ sub inject_mite_functions {
         $spec{definition_context} ||= _definition_context( 1, file => "$file", type => $kind, context => 'has declaration' );
 
         for my $name ( ref($names) ? @$names : $names ) {
-           if( my $is_extension = $name =~ s{^\+}{} ) {
-               $pkg->extend_attribute(
-                   class   => $pkg,
-                   name    => $name,
-                   %spec
-               );
-           }
-           else {
-               require Mite::Attribute;
-               my $attribute = Mite::Attribute->new(
-                   class   => $pkg,
-                   name    => $name,
-                   %spec
-               );
-               $pkg->add_attribute($attribute);
-           }
+            if( my $is_extension = $name =~ s{^\+}{} ) {
+                $pkg->extend_attribute(
+                    class   => $pkg,
+                    name    => $name,
+                    %spec
+                );
+            }
+            else {
+                require Mite::Attribute;
+                my $attribute = Mite::Attribute->new(
+                    class   => $pkg,
+                    name    => $name,
+                    %spec
+                );
+                $pkg->add_attribute($attribute);
+            }
+            my $code;
+            'CODE' eq ref( $code = $spec{builder} )
+                and *{"$package\::_build_$name"} = $code;
+            'CODE' eq ref( $code = $spec{trigger} )
+                and *{"$package\::_trigger_$name"} = $code;
+            'CODE' eq ref( $code = $spec{clone} )
+                and *{"$package\::_clone_$name"} = $code;
         }
 
         return;
@@ -228,7 +235,7 @@ sub inject_mite_functions {
                 or croak "Expected a coderef method modifier";
             ArrayRef->of(Str)->check( $names ) && @$names
                 or croak "Expected a list of method names to modify";
-            $pkg->add_required_methods( @$names );
+            $pkg->add_required_methods( @$names ) if $kind eq 'role';
             return;
         } if $requested->( $modifier, 1 );
     }
@@ -355,6 +362,11 @@ sub load_files {
 sub _load_file {
     my ( $self, $file, $inc_dir ) = @_;
 
+    if ( $self->{_already}{$file}++ ) {
+        warn "Skipping $file: already loaded\n" if $self->debug;
+        return;
+    }
+
     if ( defined $self->_project_mopper_file
     and $file eq $self->_project_mopper_file ) {
         warn "Skipping $file: it's the mop\n" if $self->debug;
@@ -564,42 +576,3 @@ sub write_default_config {
 }
 
 1;
-
-__END__
-
-=pod
-
-=head1 NAME
-
-Mite::Project - a whole project
-
-=head1 DESCRIPTION
-
-NO USER SERVICABLE PARTS INSIDE.  This is a private class.
-
-=head1 BUGS
-
-Please report any bugs to L<https://github.com/tobyink/p5-mite/issues>.
-
-=head1 AUTHOR
-
-Michael G Schwern E<lt>mschwern@cpan.orgE<gt>.
-
-Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
-
-=head1 COPYRIGHT AND LICENCE
-
-This software is copyright (c) 2011-2014 by Michael G Schwern.
-
-This software is copyright (c) 2022 by Toby Inkster.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=head1 DISCLAIMER OF WARRANTIES
-
-THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
-WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
-MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-
-=cut
